Visualize the expression of protein of interest in each target tissue by cell types.
Usage
hpaVisTissue(
data = NULL,
targetGene = NULL,
targetTissue = NULL,
targetCellType = NULL,
color = c("#FCFDBF", "#FE9F6D", "#DE4968", "#8C2981"),
customTheme = FALSE
)Arguments
- data
Input the list object generated by
hpa_download()orhpa_subset(). Require thenormal_tissuedataset. Use HPA histology data (built-in) by default.- targetGene
Vector of strings of HGNC gene symbols. By default it is set to
c('TP53', 'EGFR', 'CD44', 'PTEN'). You can also mix HGNC gene symbols and ensemnl ids (start with ENSG) and they will be converted to HGNC gene symbols.- targetTissue
Vector of strings of normal tissues. Default to all.
- targetCellType
Vector of strings of normal cell types. Default to all.
- color
Vector of 4 colors used to depict different expression levels.
- customTheme
Logical argument. If
TRUE, the function will return a barebone ggplot2 plot to be customized further.
Value
This function will return a ggplot2 plot object, which can be further modified if desirable. The tissue data is visualized as a heatmap: x axis contains inquired protein and y axis contains tissue/cells of interest.
See also
Other visualization functions:
hpaVis(),
hpaVisPatho(),
hpaVisSubcell()
Examples
data("hpa_histology_data")
geneList <- c('TP53', 'EGFR', 'CD44', 'PTEN', 'IDH1', 'IDH2', 'CYCS')
tissueList <- c('breast', 'cerebellum', 'skin 1')
## A typical function call
hpaVisTissue(data=hpa_histology_data,
targetGene=geneList,
targetTissue=tissueList)
#> * WARNING: targetCellType variable not specified, visualize all.
#> >> Use hpaListParam() to list possible values for target variables.
#> Warning: No shared levels found between `names(values)` of the manual scale and the
#> data's fill values.